@@ -58,6 +58,15 @@ class setup_shortcuts:
             return element, attribute
         return element
 
+    def find_by_text(self, text, attribute=None, parent=None):
+        if not parent:
+            parent = self.driver
+        element = parent.find_element(By.XPATH, f'//*[text()[contains(.,"{text}")]]')
+        if attribute:
+            attribute = element.get_attribute(attribute)
+            return element, attribute
+        return element
+
     def finds(self, css_selector, parent=None, wait_for=None):
         if not parent:
             parent = self.driver
@@ -74,6 +83,12 @@ class setup_shortcuts:
         element = parent.find_element(By.CSS_SELECTOR, css_selector)
         element.click()
 
+    def click_by_text(self, text, parent=None):
+        if not parent:
+            parent = self.driver
+        element = parent.find_element(By.XPATH, f'//*[text()[contains(.,"{text}")]]')
+        element.click()
+
     def text(self, css_selector, parent=None):
         if not parent:
             parent = self.driver
@@ -100,11 +115,13 @@ class setup_shortcuts:
         self.driver.implicitly_wait(1)
         elements = parent.find_elements(By.CSS_SELECTOR, css_selector)
         self.driver.implicitly_wait(self.wait_for)
-        if elements and elements[0].is_displayed():
+        if elements: # and elements[0].is_displayed():
             return elements
         else:
             return []
     
     def close(self):
         if self.browser_process_id:
-            os.kill(self.browser_process_id, 15)
\ No newline at end of file
+            os.kill(self.browser_process_id, 15)
+        else:
+            self.driver.quit()
\ No newline at end of file
